@@ -26,7 +26,7 @@ from requests.exceptions import SSLError
 from urllib3 import Timeout
 
 from imecilabt.gpulab.cli.ssh_config_manager import add_job_ssh_config, command_array_to_str, sh_quote_arg, \
-    set_jobs_ssh_config
+    set_jobs_ssh_config, find_free_ssh_tunnel_port
 from imecilabt.gpulab.model.job_convert import any_jsondict_to_job2, is_jsondict_job1, is_jsondict_job2
 from imecilabt.gpulab.model.job_event import JobEvent, JobEventType
 
@@ -186,7 +186,7 @@ def _port_mapping_format(port_mappings: List[Job2PortMapping]) -> str:
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
-GPULAB_VERSION = '3.3.0'
+GPULAB_VERSION = '3.3.2'
 
 
 def check_and_warn_version(ctx):
@@ -344,7 +344,7 @@ def modify_usage_error():
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def cli(ctx: click.Context, cert, password, deployment_environment: str, servercert, debug, custom_master_url):
-    """GPULab client version 3.3.0
+    """GPULab client version 3.3.2
 
     \b
     This is the general help. For help with a specific command, try:
@@ -577,7 +577,7 @@ def print_bugreport_context(ctx):
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def localhost_mode_cli(ctx):
-    """GPULab client version 3.3.0 (in LOCALHOST_MODE!)
+    """GPULab client version 3.3.2 (in LOCALHOST_MODE!)
 
     \b
     Send bugreports, questions and feedback to: gpulab@ilabt.imec.be
@@ -1723,7 +1723,7 @@ def actual_ssh(ctx, job_id, show, show_ansible, proxy, *, sftp_command=None):
                     # FileZilla ignores ~/.ssh/config !
                     # and it does not support SSH proxies
                     # So we need to setup the tunnel ourself
-                    local_tunnel_port = 2222
+                    local_tunnel_port = find_free_ssh_tunnel_port(debug)
                     local_tunnel_hostname = 'localhost'
 
                     filezilla_command = [
